@@ -3,7 +3,7 @@ package HTML::TurboForm::Element;
 use warnings;
 use strict;
 use base qw/ Class::Accessor /;
-__PACKAGE__->mk_accessors( qw/ params submit pure default dbsearchfield dbdata dbop dbid dblabel ignore_dbix type id name label text value request options class left_class right_class row_class attributes table submit columns / );
+__PACKAGE__->mk_accessors( qw/ params submit wrapper pure default dbsearchfield dbdata dbop dbid dblabel ignore_dbix type id name label text value request options class left_class right_class row_class attributes table submit columns / );
 
 sub new{
     my ($class, $request) = @_;
@@ -23,7 +23,7 @@ sub new{
        }
     }
 
-    if ($self->submit){
+    if ($self->submit){        
         @{$self->{modules}} = ('jquery/jquery');
         $self->{js} = ' $("#'.$self->name.'").'.$self->submit.'(function(){$("form")[0].submit(); });  ';
     }
@@ -54,16 +54,20 @@ sub add_options{
 }
 
 sub reset_options{
-   my ($self, $opt, $dblabel, $dbid) = @_;
+   my ($self, $opt) = @_;
    $self->{dbdata}=[];
    $self->{options}=[];
-   foreach (@{$opt}){ push(@{$self->options}, $_->$dbid);  }
+   $self->{options} = $opt;
 }
 
 sub freeze{
     my($self) =@_;
 }
 
+sub populate{
+    my($self) =@_;
+}
+
 sub get_attr{
     my ($self) =@_;
     my $result="";
@@ -110,7 +114,8 @@ sub vor{
 
     return "" if ( $self->pure );
     my $error='';
-    $error=$options->{error_message};
+    
+    $error=$options->{error_message} if $options->{error_message};
     my $result='';
     my $table='';
 
@@ -134,18 +139,18 @@ sub vor{
     }
 
     if ($self->{view} eq 'table') {
-        $error='<tr><td colspan="2" class="form_error">'.$error.'</td></tr>' if ($error ne '');
+        $error='<tr><td colspan="2">'.$error.'</td></tr>' if ($error ne '');
 
  $table='' if (!$table);
  $error='' if (!$error);
- $class='' if (!$class);
+ $class='';
  $rwc='' if (!$rwc);
  $rtc='' if (!$rtc);
  $self->label('') if (!$self->label);
 
         $result = $table. $error. "<tr ". $class. $rwc.">".
-                       "<td class='form_left'".$ltc.">".$self->label."</td>".
-                       "<td class='form_right'".$rtc.">";
+                       "<td ".$ltc.">".$self->label."</td>".
+                       "<td ".$rtc.">";
 
         $result=$table.'<tr><td colspan="2" '.$class.$rwc.'>' if ($self->type eq "Html");
     }
@@ -156,6 +161,15 @@ sub vor{
         $result.=$error.'<br />' if ($error ne '');
     }
 
+    if ($self->wrapper){		  
+		my $wrap=$self->wrapper;
+		$wrap=~s/<label>/$self->label/g;
+		$wrap=~s/<error>/$error/g if ($error ne '');
+		my $pos=index($wrap,'<element>');
+		$result=substr($wrap,0,$pos);
+		$self->{after_wrap}=$result=substr($wrap,$pos+10);
+	}
+
     return $result;
 }
 
@@ -169,6 +183,10 @@ sub nach{
     $result="</div>" if ($self->type eq "Html");
     $result="</td></tr>"  if ($self->{view} eq 'table');
     $result="</td>"  if ($self->{view} eq 'column');
+	
+	if ($self->wrapper){
+		$result=$self->{after_wrap} if ($self->{after_wrap});
+	}
 
     $result.="\n";
     return $result;
@@ -178,7 +196,6 @@ sub get_value{
     my ($self) = @_;
     my $result='';
     $result=$self->{request}->{$self->name} if exists($self->{request}->{$self->name});
-
     return $result;
 }
 
